==> sickgear-0.23.14nb3.tgz: lib/sickgear/readme.md <==
<hr>
<div><a id="top"><img alt="SickGear" width="200" src="https://raw.githubusercontent.com/wiki/SickGear/SickGear.Wiki/images/SickGearLogo.png"></a></div>
*SickGear*, a usenet and bittorrent PVR
<hr>

SickGear provides management of TV shows and/or Anime, it detects new episodes, links downloader apps, and more.

#### Why SickGear?
* SickGear maintains a perfect uptime with the longest track record of being stable, reliable, and trusted to work
* SickGear gives fast issue resolution and provider updates (historically, with 99% of provider updates under 24 hours)
* SickGear has the least issues and the least number of changes that require even more "fixes", less is more
* SickGear Wiki pages are updated from feedback and the supported providers list is accurate and true
* SickGear delivers valued quality from active development with a wealth of options on a dark or light themed interface
* SickGear is said to be, simply the bestest all round SickBeard descendant there is, not our words, and very humbling

#### What now?
Hey you made it here, first, welcome to SickGear! You can dive straight in, or better to read below for what to expect...
* [Install guides](https://github.com/SickGear/SickGear/wiki/Installation-Instructions) for many platforms
* [Migrating](https://github.com/SickGear/SickGear/wiki/Install-SickGear-%5B0%5D-Migrate) to a hassle free and feature rich set up is super simple

Here's a taster for what to expect...

## Some of the sick innovative gear you get
* Ideas of shows to add from Trakt, IMDb, and AniDB categories; anticipating, new seasons, new shows, popular, and more
* Advanced add show finder that near always returns results sorted A-Z, Aired, or Relevancy, with known shows separated
* Releases can be auto fetched when a show is adding (e.g. optionally fetch oldest and/or newest without further effort)
* Advanced automated search always works to save you from wasting your time manually picking from result lists
* Choose to delete watched episodes pulled directly from played media at Kodi, Emby, and/or Plex (without Trakt tracking!)
* Each show can keep all, or any set number of most recent episodes; e.g. only keep daily releases from the last 40 days
* Smart custom qualities selector that guides to achieve an optimal quality selection for automated episode search
* Choose to have episodes upgraded in quality, or keep existing archive quality, and upgrade future episodes either way
* Single out providers to target "scene releases" either exclusively, with fallbacks to non-scene, and with optional exclusions
* Mark providers to avoid "scene nuked" releases, with optional fallback when no other choice is available
* Natively use a most powerful regex pattern matching system for superior information handling
* Select a UI style anytime; Regular, Proview I, or Proview II - independently for Daily Schedule, and for Display Show
* Smart fanart system allows you to rate avoid/prefer. UI can be moved or toggled off/on to fully appreciate a fanart
* Daily Schedule Layout "Day by Day" displays fanart backgrounds of imminent releases
* Configure from 0 to 500 fanart images to cache per show, default is 3
* Provider server failure charts display what failed, when and why
* Provider server failure handler that pauses connecting to a server the more it fails
* Provider server activity graph and stats display how each are performing
* Integrated IsItDownRightNow buttons for the used TVDB, TheXem, and Github sites to see if any are/were offline
* Built-in providers that have proved over time to deliver leading durability among its application class and third parties
* Secure support of Cloudflare IUAM access with no need to install node.js
* Built-in Kodi repository service to maintain SickGear add-ons, the first add-on is Watched State Updater
* Separate Plex server and Plex client settings, multiple LAN Plex server support, and Plex Home multiple user support
* Intelligent library updates target the actual Plex server that carries the show of an episode (multi LAN server)
* NZBGet to SickGear direct connection using a purpose built add-on
* Communicate directly with qBittorrent/Deluge/Transmission etc. using a dedicated integration script
* Proxy auto-config (PAC) support to define when a proxy is used instead of using one for every system request
* Change file date, to the date that the episode aired (feature first created here for XBMC file list sorting)
* Visual percentage progress of managed episodes
* Configure an episode status for removed media files
* Configurable default home page

Innovations also exist in core, we often inspire imitators, but you can [get the real gear!](https://github.com/SickGear/SickGear/wiki/Installation-Instructions)

Other features and worthy points;
* Stable, quality assured testing and development cycle
* Most comprehensive selection of usenet and torrent sources
* Compatible with any platform via a familiar web interface
* Episode management
  * Group shows into personalised sections
  * View missed and upcoming shows at a glance with "day by day" and other layouts
  * Automatic and manual search for availability of episodes you want
  * Well known established sources are used to gather reliable show information
  * Known and user editable alternative show names can be searched
  * Known and user editable alternative numbered seasons and/or episodes can be searched
  * Forward search results directly to clients like NZBGet, SABNZBd, qBitTorrent, Deluge and others
  * Save search results to a "blackhole" folder, a place designated for clients to auto scan
  * Built-in post processing of episodes, with renaming to custom folder and/or file names
  * Fetch metadata like fanart, poster and banner images, nfo's for clients like Kodi, Emby, Plex, Jellyfin and many more
  * Native advanced automated handling of failed downloads to ensure a success after failure
  * Overview of episodes, rating, version, airdate, episode status ([their meaning](https://github.com/SickGear/SickGear/wiki/Status-Modes))
  * Support for specials and multi episode media files
* File management for media processing
  * Configurable folder/file renaming for a consistent library
  * Automatic unpacking of rar archives
* Automated subtitle management
* Notification
  * Home Theater/NAS (Emby, Kodi, Plex, Syno, Tivo, and more) can be notified to update their library
  * Social notifiers (Trakt, Slack, Gitter, Discord, E-mail, and more)
  * Device notifiers (Boxcar2, Growl, Prowl, and more)
* Server friendly with minimal number of API calls using both active and passive search tech
* Automated alternative show names and episode numbering from XEM

## Screenies
<table><thead></thead><tbody>
<tr align="center">
  <td><a title="Show List - Layout: Simple" href="https://raw.githubusercontent.com/wiki/SickGear/SickGear/images/screenies/showlist-simple.jpg"><img src="https://raw.githubusercontent.com/wiki/SickGear/SickGear/images/screenies/showlist-simple-t.jpg" width="200"></a></td>
  <td><a title="Show List - Layout: Banner" href="https://raw.githubusercontent.com/wiki/SickGear/SickGear/images/screenies/showlist-banner.jpg"><img src="https://raw.githubusercontent.com/wiki/SickGear/SickGear/images/screenies/showlist-banner-t.jpg" width="200"></a></td>
  <td><a title="Show List - Layout: Poster" href="https://raw.githubusercontent.com/wiki/SickGear/SickGear/images/screenies/showlist-poster.jpg"><img src="https://raw.githubusercontent.com/wiki/SickGear/SickGear/images/screenies/showlist-poster-t.jpg" width="200"></a></td>
  <td><a title="Daily Schedule - Layout: Day by Day" href="https://raw.githubusercontent.com/wiki/SickGear/SickGear/images/screenies/episodeview-day-by-day.jpg"><img src="https://raw.githubusercontent.com/wiki/SickGear/SickGear/images/screenies/episodeview-day-by-day-t.jpg" width="200"></a></td>
  <td><a title="Daily Schedule - Layout: List" href="https://raw.githubusercontent.com/wiki/SickGear/SickGear/images/screenies/episodeview-list.jpg"><img src="https://raw.githubusercontent.com/wiki/SickGear/SickGear/images/screenies/episodeview-list-t.jpg" width="200"></a></td>
  <td><a title="Display Show" href="https://raw.githubusercontent.com/wiki/SickGear/SickGear/images/screenies/displayshow.jpg"><img src="https://raw.githubusercontent.com/wiki/SickGear/SickGear/images/screenies/displayshow-t.jpg" width="200"></a></td>
  <td><a title="Add from Trakt" href="https://raw.githubusercontent.com/wiki/SickGear/SickGear/images/screenies/addshow-trakt.gif"><img src="https://raw.githubusercontent.com/wiki/SickGear/SickGear/images/screenies/addshow-trakt-t.jpg" width="200"></a></td>
  <td><a title="Edit Show" href="https://raw.githubusercontent.com/wiki/SickGear/SickGear/images/screenies/editshow.gif"><img src="https://raw.githubusercontent.com/wiki/SickGear/SickGear/images/screenies/editshow-t.jpg" width="200"></a></td>
</tr>
<tr align="center">
  <td>Show List: Simple<br />Theme: <a title="Theme Dark" href="https://raw.githubusercontent.com/wiki/SickGear/SickGear/images/screenies/showlist-simple.jpg">Dark</a>, <a title="Theme Light" href="https://raw.githubusercontent.com/wiki/SickGear/SickGear/images/screenies/showlist-simple-light.jpg">Light</a></td>
  <td>Show List: Banner<br />Theme: <a title="Theme Dark" href="https://raw.githubusercontent.com/wiki/SickGear/SickGear/images/screenies/showlist-banner.jpg">Dark</a>, <a title="Theme Light" href="https://raw.githubusercontent.com/wiki/SickGear/SickGear/images/screenies/showlist-banner-light.jpg">Light</a></td>
  <td>Show List: Poster<br />Theme: <a title="Theme Dark - Anime" href="https://raw.githubusercontent.com/wiki/SickGear/SickGear/images/screenies/showlist-poster.jpg">Dark</a>, <a title="Theme Dark 2" href="https://raw.githubusercontent.com/wiki/SickGear/SickGear/images/screenies/showlist-poster2.jpg">Dark 2</a></td>
  <td>Daily Schedule: Day by Day<br />Theme: <a title="Theme Dark" href="https://raw.githubusercontent.com/wiki/SickGear/SickGear/images/screenies/episodeview-day-by-day.jpg">Dark</a>, <a title="Theme Light" href="https://raw.githubusercontent.com/wiki/SickGear/SickGear/images/screenies/episodeview-day-by-day-light.jpg">Light</a></td>
  <td>Daily Schedule: List<br />Theme: <a title="Theme Dark" href="https://raw.githubusercontent.com/wiki/SickGear/SickGear/images/screenies/episodeview-list.jpg">Dark</a>, <a title="Theme Dark - Anime" href="https://raw.githubusercontent.com/wiki/SickGear/SickGear/images/screenies/episodeview-list2.jpg">Dark 2</a>, <a title="Theme Light" href="https://raw.githubusercontent.com/wiki/SickGear/SickGear/images/screenies/episodeview-list-light.jpg">Light</a></td>
  <td>Display Show<br />Theme: <a title="Theme Dark" href="https://raw.githubusercontent.com/wiki/SickGear/SickGear/images/screenies/displayshow.jpg">Dark</a>, <a title="Theme Light" href="https://raw.githubusercontent.com/wiki/SickGear/SickGear/images/screenies/displayshow-light.jpg">Light</a></td>
  <td>Add from Trakt<br />Theme: <a title="Theme Dark" href="https://raw.githubusercontent.com/wiki/SickGear/SickGear/images/screenies/addshow-trakt.gif">Dark</a></td>
  <td>Edit Show<br />Theme: <a title="Theme Dark" href="https://raw.githubusercontent.com/wiki/SickGear/SickGear/images/screenies/editshow.gif">Dark</a></td>
</tr>
</tbody>
</table>

## Available versions
<table><thead></thead><tbody>
<tr align="center">
  <td>Master (<a title="Master Changelog" href="../master/CHANGES.md">changes</a>)</td><td>(most stable)</td><td><a id="top" title=""><img src="https://raw.githubusercontent.com/wiki/SickGear/SickGear/images/badge-stability.png"></a></td><td><a id="top" title="Build Status: Stable = Terrific!"><img src="https://raw.githubusercontent.com/wiki/SickGear/SickGear/images/badge-stable.png"></a></td>
</tr>
<tr align="center">
  <td>Develop (<a title="Develop Changelog" href="../develop/CHANGES.md">changes</a>)</td><td>(mostly stable)</td><td><a id="top" title="Where some imitate"><img src="https://raw.githubusercontent.com/wiki/SickGear/SickGear/images/badge-innovate.png"></a></td><td><a title="Build Status: Passing = All good!" target="_blank" href="https://travis-ci.com/SickGear/SickGear"><img src="https://api.travis-ci.com/SickGear/SickGear.svg?branch=develop"></a></td>
</tr>
<tr align="center">
  <td colspan=5>[ ++ Install <a href="https://github.com/SickGear/SickGear/wiki/Installation-Instructions">Guides</a> ++ ][ Frequently <a href="https://github.com/SickGear/SickGear/wiki/Frequently-Answered-Questions">Answered</a> ][ Discover <a href="https://github.com/SickGear/SickGear/wiki">Wiki</a> ]</td>
</tr>
<tr align="center">
  <td>Github Stats</td><td>(reliability)</td><td><a href="http://isitmaintained.com/project/SickGear/SickGear" title="Average time to resolve an issue"><img title="Average time to resolve an issue" src="http://isitmaintained.com/badge/resolution/SickGear/SickGear.svg"></a></td><td><a href="http://isitmaintained.com/project/SickGear/SickGear" title="Percentage of issues still open"><img title="Percentage of issues still open" src="http://isitmaintained.com/badge/open/SickGear/SickGear.svg"></a></td>
</tr>
</tbody>
</table>

## Howto

#### Report issues
The following [guidelines](https://github.com/SickGear/SickGear/wiki/%5BHow-to%5D-Report-Issues) prevent reported issues getting messy and help us quickly get to the nub of an issue.  Please be aware that we require all requested information and that missing details will likely result in the reported issue being closed.

#### Contribute code
Please read this [guide](https://github.com/SickGear/SickGear/wiki/%5BHow-to%5D-Contribute-Code).  Directions include coding with git and submitting pull requests.
If your pull request is a new feature, please try explaining its function to a limit of 200 characters.  Better, talk to our devs in IRC (details below).

## Contributors

#### To core
MidgetSpy, zoggy, 1337, Tolstyak, Mr_Orange, Bricky, JackDandy, Prinz23, Supremicus, adam111316, and zanaga

#### In other areas, testers and QA
Warm thanks to tehspede, CtrlAltDefeat, Mike, vergessen (betrayed), and Rawh for their keen eye, all around help, and making sure all manner of things work as expected

#### Provider code
Thanks also, to unsung heroes that added source providers; Idan Gutman, Daniel Heimans, jkaberg, and Seedboy

Finally, a massive thanks to all those that remain in the shadows, the quiet ones who welcome folk to special places, we salute you for your hospitality and for tirelessly keeping up operations.

## Community
* <a href="https://gitter.im/SickGear/"><img src="https://badges.gitter.im/sickgear.svg"></a> web based (most likely one on one with a dev)
* <a name="freenode"><img src="https://img.shields.io/badge/style-join%20chat-blue.svg?style=flat.svg&label=freenode"></a>&nbsp;(`irc.freenode.net` channel `#SickGear`)

Although support is available, you should understand the basics of your OS.  If you can't understand locating a db file, not running as root, or setting file permissions, then SickGear might not be for you.

---
Enjoy SickGear - stability, reliability, assured.

==> sickgear-3.30.5nb3.tgz: lib/sickgear/readme.md <==
<hr>
<div><a id="top"><img alt="SickGear" width="200" src="https://raw.githubusercontent.com/wiki/SickGear/SickGear.Wiki/images/SickGearLogo.png"></a></div>
*SickGear*, a usenet and bittorrent PVR
<hr>

SickGear provides management of TV shows and/or Anime, it detects new episodes, links downloader apps, and more.

#### Why SickGear?
* SickGear maintains a perfect uptime with the longest track record of being stable, reliable, and trusted to work
* SickGear gives fast issue resolution and provider updates (historically, with 99% of provider updates under 24 hours)
* SickGear has the least issues and the least number of changes that require even more "fixes", less is more
* SickGear Wiki pages are updated from feedback and the supported providers list is accurate and true
* SickGear delivers valued quality from active development with a wealth of options on a dark or light themed interface
* SickGear is said to be, simply the bestest all round SickBeard descendant there is, not our words, and very humbling

#### What now?
Hey you made it here, first, welcome to SickGear! You can dive straight in, or better to read below for what to expect...
* [Install guides](https://github.com/SickGear/SickGear/wiki/Installation-Instructions) for many platforms
* [Migrating](https://github.com/SickGear/SickGear/wiki/Install-SickGear-%5B0%5D-Migrate) to a hassle free and feature rich set up is super simple

Here's a taster for what to expect...

## Some of the sick innovative gear you get
* Ideas of shows to add from Trakt, IMDb, and AniDB categories; anticipating, new seasons, new shows, popular, and more
* Advanced add show finder that near always returns results sorted A-Z, Aired, or Relevancy, with known shows separated
* Releases can be auto fetched when a show is adding (e.g. optionally fetch oldest and/or newest without further effort)
* Advanced automated search always works to save you from wasting your time manually picking from result lists
* Choose to delete watched episodes pulled directly from played media at Kodi, Emby, and/or Plex (without Trakt tracking!)
* Each show can keep all, or any set number of most recent episodes; e.g. only keep daily releases from the last 40 days
* Smart custom qualities selector that guides to achieve an optimal quality selection for automated episode search
* Choose to have episodes upgraded in quality, or keep existing archive quality, and upgrade future episodes either way
* Single out providers to target "scene releases" either exclusively, with fallbacks to non-scene, and with optional exclusions
* Mark providers to avoid "scene nuked" releases, with optional fallback when no other choice is available
* Natively use a most powerful regex pattern matching system for superior information handling
* Select a UI style anytime; Regular, Proview I, or Proview II - independently for Daily Schedule, and for Display Show
* Smart fanart system allows you to rate avoid/prefer. UI can be moved or toggled off/on to fully appreciate a fanart
* Daily Schedule Layout "Day by Day" displays fanart backgrounds of imminent releases
* Configure from 0 to 500 fanart images to cache per show, default is 3
* Provider server failure charts display what failed, when and why
* Provider server failure handler that pauses connecting to a server the more it fails
* Provider server activity graph and stats display how each are performing
* Integrated IsItDownRightNow buttons for the used TVDB, TheXem, and Github sites to see if any are/were offline
* Built-in providers that have proved over time to deliver leading durability among its application class and third parties
* Secure support of Cloudflare IUAM access with no need to install node.js
* Built-in Kodi repository service to maintain SickGear add-ons, the first add-on is Watched State Updater
* Separate Plex server and Plex client settings, multiple LAN Plex server support, and Plex Home multiple user support
* Intelligent library updates target the actual Plex server that carries the show of an episode (multi LAN server)
* NZBGet to SickGear direct connection using a purpose built add-on
* Communicate directly with qBittorrent/Deluge/Transmission etc. using a dedicated integration script
* Proxy auto-config (PAC) support to define when a proxy is used instead of using one for every system request
* Change file date, to the date that the episode aired (feature first created here for XBMC file list sorting)
* Visual percentage progress of managed episodes
* Configure an episode status for removed media files
* Configurable default home page

Innovations also exist in core, we often inspire imitators, but you can [get the real gear!](https://github.com/SickGear/SickGear/wiki/Installation-Instructions)

Other features and worthy points;
* Stable, quality assured testing and development cycle
* Most comprehensive selection of usenet and torrent sources
* Compatible with any platform via a familiar web interface
* Episode management
  * Group shows into personalised sections
  * View missed and upcoming shows at a glance with "day by day" and other layouts
  * Automatic and manual search for availability of episodes you want
  * Well known established sources are used to gather reliable show information
  * Known and user editable alternative show names can be searched
  * Known and user editable alternative numbered seasons and/or episodes can be searched
  * Forward search results directly to clients like NZBGet, SABNZBd, qBitTorrent, Deluge and others
  * Save search results to a "blackhole" folder, a place designated for clients to auto scan
  * Built-in post processing of episodes, with renaming to custom folder and/or file names
  * Fetch metadata like fanart, poster and banner images, nfo's for clients like Kodi, Emby, Plex, Jellyfin and many more
  * Native advanced automated handling of failed downloads to ensure a success after failure
  * Overview of episodes, rating, version, airdate, episode status ([their meaning](https://github.com/SickGear/SickGear/wiki/Status-Modes))
  * Support for specials and multi episode media files
* File management for media processing
  * Configurable folder/file renaming for a consistent library
  * Automatic unpacking of rar archives
* Automated subtitle management
* Notification
  * Home Theater/NAS (Emby, Kodi, Plex, Syno, Tivo, and more) can be notified to update their library
  * Social notifiers (Trakt, Slack, Gitter, Discord, E-mail, and more)
  * Device notifiers (Boxcar2, Growl, Prowl, and more)
* Server friendly with minimal number of API calls using both active and passive search tech
* Automated alternative show names and episode numbering from XEM

## Screenies
<table><thead></thead><tbody>
<tr align="center">
  <td><a title="Show List - Layout: Simple" href="https://raw.githubusercontent.com/wiki/SickGear/SickGear/images/screenies/showlist-simple.jpg"><img src="https://raw.githubusercontent.com/wiki/SickGear/SickGear/images/screenies/showlist-simple-t.jpg" width="200"></a></td>
  <td><a title="Show List - Layout: Banner" href="https://raw.githubusercontent.com/wiki/SickGear/SickGear/images/screenies/showlist-banner.jpg"><img src="https://raw.githubusercontent.com/wiki/SickGear/SickGear/images/screenies/showlist-banner-t.jpg" width="200"></a></td>
  <td><a title="Show List - Layout: Poster" href="https://raw.githubusercontent.com/wiki/SickGear/SickGear/images/screenies/showlist-poster.jpg"><img src="https://raw.githubusercontent.com/wiki/SickGear/SickGear/images/screenies/showlist-poster-t.jpg" width="200"></a></td>
  <td><a title="Daily Schedule - Layout: Day by Day" href="https://raw.githubusercontent.com/wiki/SickGear/SickGear/images/screenies/episodeview-day-by-day.jpg"><img src="https://raw.githubusercontent.com/wiki/SickGear/SickGear/images/screenies/episodeview-day-by-day-t.jpg" width="200"></a></td>
  <td><a title="Daily Schedule - Layout: List" href="https://raw.githubusercontent.com/wiki/SickGear/SickGear/images/screenies/episodeview-list.jpg"><img src="https://raw.githubusercontent.com/wiki/SickGear/SickGear/images/screenies/episodeview-list-t.jpg" width="200"></a></td>
  <td><a title="Display Show" href="https://raw.githubusercontent.com/wiki/SickGear/SickGear/images/screenies/displayshow.jpg"><img src="https://raw.githubusercontent.com/wiki/SickGear/SickGear/images/screenies/displayshow-t.jpg" width="200"></a></td>
  <td><a title="Edit Show" href="https://raw.githubusercontent.com/wiki/SickGear/SickGear/images/screenies/editshow.mp4"><img src="https://raw.githubusercontent.com/wiki/SickGear/SickGear/images/screenies/editshow-t.jpg" width="200"></a></td>
</tr>
<tr align="center">
  <td>Show List: Simple<br />Theme: <a title="Theme Dark" href="https://raw.githubusercontent.com/wiki/SickGear/SickGear/images/screenies/showlist-simple.jpg">Dark</a>, <a title="Theme Light" href="https://raw.githubusercontent.com/wiki/SickGear/SickGear/images/screenies/showlist-simple-light.jpg">Light</a></td>
  <td>Show List: Banner<br />Theme: <a title="Theme Dark" href="https://raw.githubusercontent.com/wiki/SickGear/SickGear/images/screenies/showlist-banner.jpg">Dark</a>, <a title="Theme Light" href="https://raw.githubusercontent.com/wiki/SickGear/SickGear/images/screenies/showlist-banner-light.jpg">Light</a></td>
  <td>Show List: Poster<br />Theme: <a title="Theme Dark - Anime" href="https://raw.githubusercontent.com/wiki/SickGear/SickGear/images/screenies/showlist-poster.jpg">Dark</a>, <a title="Theme Dark 2" href="https://raw.githubusercontent.com/wiki/SickGear/SickGear/images/screenies/showlist-poster2.jpg">Dark 2</a></td>
  <td>Daily Schedule: Day by Day<br />Theme: <a title="Theme Dark" href="https://raw.githubusercontent.com/wiki/SickGear/SickGear/images/screenies/episodeview-day-by-day.jpg">Dark</a>, <a title="Theme Light" href="https://raw.githubusercontent.com/wiki/SickGear/SickGear/images/screenies/episodeview-day-by-day-light.jpg">Light</a></td>
  <td>Daily Schedule: List<br />Theme: <a title="Theme Dark" href="https://raw.githubusercontent.com/wiki/SickGear/SickGear/images/screenies/episodeview-list.jpg">Dark</a>, <a title="Theme Dark - Anime" href="https://raw.githubusercontent.com/wiki/SickGear/SickGear/images/screenies/episodeview-list2.jpg">Dark 2</a>, <a title="Theme Light" href="https://raw.githubusercontent.com/wiki/SickGear/SickGear/images/screenies/episodeview-list-light.jpg">Light</a></td>
  <td>Display Show<br />Theme: <a title="Theme Dark" href="https://raw.githubusercontent.com/wiki/SickGear/SickGear/images/screenies/displayshow.jpg">Dark</a>, <a title="Theme Light" href="https://raw.githubusercontent.com/wiki/SickGear/SickGear/images/screenies/displayshow-light.jpg">Light</a></td>
  <td>Edit Show<br />Theme: <a title="Theme Dark" href="https://raw.githubusercontent.com/wiki/SickGear/SickGear/images/screenies/editshow.mp4">Dark</a></td>
</tr>
</tbody>
</table>

## Available versions
<table><thead></thead><tbody>
<tr align="center">
  <td>Main (<a title="Main Changelog" href="../main/CHANGES.md">changes</a>)</td><td>(most stable)</td><td><a id="top" title=""><img src="https://raw.githubusercontent.com/wiki/SickGear/SickGear/images/badge-stability.png"></a></td><td><a id="top" title="Build Status: Stable = Terrific!"><img src="https://raw.githubusercontent.com/wiki/SickGear/SickGear/images/badge-stable.png"></a></td>
</tr>
<tr align="center">
  <td>Dev (<a title="Dev Changelog" href="../dev/CHANGES.md">changes</a>)</td><td>(mostly stable)</td><td><a id="top" title="Where some imitate"><img src="https://raw.githubusercontent.com/wiki/SickGear/SickGear/images/badge-innovate.png"></a></td><td><a title="Build Status: Passing = All good!" target="_blank" href="https://travis-ci.com/SickGear/SickGear"><img src="https://api.travis-ci.com/SickGear/SickGear.svg?branch=develop"></a></td>
</tr>
<tr align="center">
  <td colspan=5>[ ++ Install <a href="https://github.com/SickGear/SickGear/wiki/Installation-Instructions">Guides</a> ++ ][ Frequently <a href="https://github.com/SickGear/SickGear/wiki/Frequently-Answered-Questions">Answered</a> ][ Discover <a href="https://github.com/SickGear/SickGear/wiki">Wiki</a> ]</td>
</tr>
<tr align="center">
  <td>Github Stats</td><td>(reliability)</td><td><a href="http://isitmaintained.com/project/SickGear/SickGear" title="Average time to resolve an issue"><img title="Average time to resolve an issue" src="http://isitmaintained.com/badge/resolution/SickGear/SickGear.svg"></a></td><td><a href="http://isitmaintained.com/project/SickGear/SickGear" title="Percentage of issues still open"><img title="Percentage of issues still open" src="http://isitmaintained.com/badge/open/SickGear/SickGear.svg"></a></td>
</tr>
</tbody>
</table>

## Howto

#### Report issues
The following [guidelines](https://github.com/SickGear/SickGear/wiki/%5BHow-to%5D-Report-Issues) prevent reported issues getting messy and help us quickly get to the nub of an issue.  Please be aware that we require all requested information and that missing details will likely result in the reported issue being closed.

## Community
* <a name="libera"><img src="https://img.shields.io/badge/style-join%20chat-blue.svg?style=flat.svg&label=irc.libera.chat"></a>&nbsp;(`irc.libera.chat` channel `#sickgear`)

---
Enjoy SickGear - stability, reliability, assured.
